==> nextcloud-app-news-1:25.2.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/pt_PT.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Pedido falhou, ligação à rede indisponível!",
    "Request unauthorized. Are you logged in?" : "Pedido não autorizado. Fez o login?",
    "Token expired or app not enabled! Reload the page!" : "Token expirou ou aplicação não ativa! Recarregue a página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Erro interno do servidor. Veja por favor o ficheiro na pasta data/nextcloud.log para mais informações!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Falha no pedido, Nextcloud está atualmente em modo de manutenção!",
    "News feeds" : "Feeds de notícias",
    "Unread articles" : "Artigos não lidos",
    "News" : "Notícias",
    "News folders" : "Novas pastas",
    "Shared with me" : "Partilhadas comigo",
    "An RSS/Atom feed reader" : "Leitor de feeds RSS/Atom",
    "Download" : "Transferir",
    "Close" : "Fechar",
    "Web address" : "Endereço da Web",
    "No folder" : "Sem Pasta",
    "Folder name" : "Nome da pasta",
    "Username" : "Nome de utilizador",
    "Password" : "Senha",
    "Feed exists already!" : "A feed já existe!",
    "New folder" : "Nova Pasta",
    "Folder exists already!" : "A pasta já existe!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "As credenciais de autenticação básica HTTP têm de ser armazenadas de forma não encriptada. Qualquer pessoa com acesso ao servidor ou base de dados poderá vê-las!",
    "Credentials" : "Credenciais",
    "Subscribe" : "Subscrever",
    "Maximum read count per feed" : "Número máximo de leituras por feed",
    "Maximum redirects" : "Máximo de redirecionamentos",
    "Feed fetcher timeout" : "A obtenção do feed expirou",
    "Explore Service URL" : "Explorar Serviço URL",
    "Update interval" : "Intervalo de actualização",
    "Use system cron for updates" : "Use o programador do sistema para as atualizações",
    "Disable this if you use a custom updater." : "Desative isto se é um sistema de atualizações feito à medida.",
    "Move" : "Mover",
    "Share" : "Partilhar",
    "Share with" : "Partilhar com",
    "Mark read" : "Marcar como lido",
    "All articles" : "Todos os artigos",
    "Starred" : "Marcado",
    "Explore" : "Explorar",
    "Settings" : "Definições",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Disable mark read through scrolling" : "Desativar marcar ler através de movimento",
    "Show all articles" : "Mostrar todos os artigos",
    "Reverse ordering (oldest on top)" : "Ordem inversa (antigos no topo)",
    "Default" : "Predefinido",
    "Rename" : "Renomear",
    "Delete" : "Apagar",
    "Rename Feed" : "Renomear <em>Feed</em>",
    "Newest first" : "Recentes primeiro",
    "Oldest first" : "Antigos primeiro",
    "Toggle star article" : "Alternar estrela do artigo",
    "Mark unread" : "Marcar como não lido",
    "by" : "por",
    "from" : "de",
    "shared by" : "partilhado por",
    "Play audio" : "Reproduzir áudio",
    "Download audio" : "Transferir áudio",
    "Download video" : "Transferir vídeo",
    "Open website" : "Abrir site da web",
    "Keep article unread" : "Marcar artigo como não lido",
    "Toggle keep current article unread" : "Alternar manter o artigo atual como não lido",
    "Remove keep article unread" : "Remover marcação de artigo não lido",
    "Last update" : "Último refrescamento",
    "Title" : "Título",
    "Not available" : "Não disponível",
    "Keyboard shortcut" : "Atalho de teclado",
    "Jump to next article" : "Ir para o artigo seguinte",
    "Jump to previous article" : "Ir para o artigo anterior",
    "right" : "direita",
    "left" : "esquerda",
    "Star article and jump to next one" : "Destacar artigo e saltar para o próximo",
    "Open article in new tab" : "Abrir artigo num separador novo",
    "Refresh" : "Atualizar",
    "Load next feed" : "Carregar feed seguinte",
    "Load previous feed" : "Carregar feed anterior",
    "Load previous folder" : "Carregar pasta anterior",
    "Load next folder" : "Carregar pasta seguinte",
    "Scroll to active navigation entry" : "Vá até a entrada de navegação ativa",
    "Shift" : "Shift",
    "How to set up the operating system cron" : "Como configurar o cron no sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um actualizador paralelo mais rápido que use a API de actualizações da aplicação Notícias",
    "No articles available" : "Não há artigos disponíveis",
    "No unread articles available" : "Não há artigos por ler disponíveis",
    "Star article" : "Destacar artigo",
    "Unstar article" : "Retirar destaque",
    "No users found" : "Não foram encontrados utilizadores",
    "Description" : "Descrição",
    "Toggle expand article in compact view" : "Alternar expandir artigo na visulaização compacta",
    "Mark current article's feed/folder read" : "Marcar a pasta/feed do artigo atual como lida",
    "Folder" : "Pasta",
    "Go back" : "Voltar",
    "New Folder" : "Nova Pasta",
    "Create" : "Criar",
    "Update failed more than 50 times" : "A atualização falhou mais de 50 vezes",
    "Deleted feed" : "Apagar feed",
    "Undo delete feed" : "Desfazer apagar a feed",
    "Menu" : "Menu",
    "Dismiss" : "Rejeitar",
    "Collapse" : "Expandir",
    "Deleted folder" : "Apagar pasta",
    "Undo delete folder" : "Anular apagar pasta",
    "Compact view" : "Visualização Compacta",
    "Expand articles on key navigation" : "Expandir artigos ao navegar por tecla",
    "Subscriptions (OPML)" : "Subscrições (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Erro na importção: OPML não contém nem feeds nem pastas",
    "Unread/Starred Articles" : "Artigos Não Lidos/Classificados",
    "Error when importing: file does not contain valid JSON" : "Ocorreu um erro na importação: o ficheiro não contém JSON válido",
    "Help" : "Ajuda",
    "Documentation" : "Documentação",
    "Report a bug" : "Reportar um erro"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-news-1:25.3.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/pt_PT.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Pedido falhou, ligação à rede indisponível!",
    "Request unauthorized. Are you logged in?" : "Pedido não autorizado. Fez o início de sessão?",
    "Token expired or app not enabled! Reload the page!" : "Token expirou ou aplicação não ativa! Recarregue a página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Erro interno do servidor. Veja por favor o ficheiro na pasta data/nextcloud.log para mais informações!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Falha no pedido, Nextcloud está atualmente em modo de manutenção!",
    "News feeds" : "Feeds de notícias",
    "Unread articles" : "Artigos não lidos",
    "News" : "Notícias",
    "News folders" : "Novas pastas",
    "Shared with me" : "Partilhadas comigo",
    "An RSS/Atom feed reader" : "Leitor de feeds RSS/Atom",
    "Download" : "Transferir",
    "Close" : "Fechar",
    "Web address" : "Endereço da Web",
    "No folder" : "Sem Pasta",
    "Folder name" : "Nome da pasta",
    "Username" : "Nome de utilizador",
    "Password" : "Senha",
    "Feed exists already!" : "A feed já existe!",
    "New folder" : "Nova Pasta",
    "Folder exists already!" : "A pasta já existe!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "As credenciais de autenticação básica HTTP têm de ser armazenadas de forma não encriptada. Qualquer pessoa com acesso ao servidor ou base de dados poderá vê-las!",
    "Credentials" : "Credenciais",
    "Subscribe" : "Subscrever",
    "Maximum read count per feed" : "Número máximo de leituras por feed",
    "Maximum redirects" : "Máximo de redirecionamentos",
    "Feed fetcher timeout" : "A obtenção do feed expirou",
    "Explore Service URL" : "Explorar Serviço URL",
    "Update interval" : "Intervalo de atualização",
    "Use system cron for updates" : "Use o programador do sistema para as atualizações",
    "Disable this if you use a custom updater." : "Desative isto se é um sistema de atualizações feito à medida.",
    "Move" : "Mover",
    "Share" : "Partilhar",
    "Share with" : "Partilhar com",
    "Default" : "Predefinido",
    "Mark read" : "Marcar como lido",
    "All articles" : "Todos os artigos",
    "Starred" : "Marcado",
    "Explore" : "Explorar",
    "Settings" : "Definições",
    "Documentation" : "Documentação",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Article feed information" : "Informação da \"feed\" do artigo",
    "Disable mark read through scrolling" : "Desativar marcar ler através de movimento",
    "Show all articles" : "Mostrar todos os artigos",
    "Reverse ordering (oldest on top)" : "Ordem inversa (antigos no topo)",
    "Rename" : "Renomear",
    "Delete" : "Apagar",
    "Rename Feed" : "Renomear Feed",
    "Open Feed URL" : "Abrir URL da Feed",
    "Newest first" : "Recentes primeiro",
    "Oldest first" : "Antigos primeiro",
    "Previous" : "Anterior",
    "Next" : "Seguinte",
    "Toggle star article" : "Alternar estrela do artigo",
    "Mark unread" : "Marcar como não lido",
    "by" : "por",
    "from" : "de",
    "shared by" : "partilhado por",
    "Play audio" : "Reproduzir áudio",
    "Download audio" : "Transferir áudio",
    "Download video" : "Transferir vídeo",
    "Open website" : "Abrir site da web",
    "Keep article unread" : "Marcar artigo como não lido",
    "Toggle keep current article unread" : "Alternar manter o artigo atual como não lido",
    "Remove keep article unread" : "Remover marcação de artigo não lido",
    "Not available" : "Não disponível",
    "Last update" : "Último refrescamento",
    "Time when the feed was last downloaded" : "A hora em que a \"feed\" foi transferida pela última vez",
    "Title" : "Título",
    "Keyboard shortcut" : "Atalho de teclado",
    "Jump to next article" : "Ir para o artigo seguinte",
    "Jump to previous article" : "Ir para o artigo anterior",
    "right" : "direita",
    "left" : "esquerda",
    "Star article and jump to next one" : "Destacar artigo e saltar para o próximo",
    "Open article in new tab" : "Abrir artigo num separador novo",
    "Refresh" : "Atualizar",
    "Load next feed" : "Carregar feed seguinte",
    "Load previous feed" : "Carregar feed anterior",
    "Load previous folder" : "Carregar pasta anterior",
    "Load next folder" : "Carregar pasta seguinte",
    "Scroll to active navigation entry" : "Vá até a entrada de navegação ativa",
    "Shift" : "Shift",
    "How to set up the operating system cron" : "Como configurar o cron no sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um atualizador paralelo mais rápido que use a API de atualizações da aplicação Notícias",
    "No articles available" : "Não há artigos disponíveis",
    "No unread articles available" : "Não há artigos por ler disponíveis",
    "Star article" : "Destacar artigo",
    "Unstar article" : "Retirar destaque",
    "No users found" : "Não foram encontrados utilizadores",
    "Description" : "Descrição",
    "Toggle expand article in compact view" : "Alternar expandir artigo na visualização compacta",
    "Mark current article's feed/folder read" : "Marcar a pasta/\"feed\" do artigo atual como lida",
    "Folder" : "Pasta",
    "Go back" : "Voltar",
    "New Folder" : "Nova Pasta",
    "Create" : "Criar",
    "Update failed more than 50 times" : "A atualização falhou mais de 50 vezes",
    "Deleted feed" : "Feed eliminada",
    "Undo delete feed" : "Anular eliminar feed",
    "Menu" : "Menu",
    "Open feed URL" : "Abrir URL da feed",
    "Dismiss" : "Rejeitar",
    "Collapse" : "Expandir",
    "Deleted folder" : "Apagar pasta",
    "Undo delete folder" : "Anular apagar pasta",
    "Compact view" : "Visualização compacta",
    "Expand articles on key navigation" : "Expandir artigos ao navegar por tecla",
    "Subscriptions (OPML)" : "Subscrições (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Erro na importção: OPML não contém nem feeds nem pastas",
    "Unread/Starred Articles" : "Artigos Não Lidos/Classificados",
    "Error when importing: file does not contain valid JSON" : "Ocorreu um erro na importação: o ficheiro não contém JSON válido",
    "Help" : "Ajuda",
    "Report a bug" : "Reportar um erro"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
